from django.shortcuts import render
from meiduo.libs.captcha.captcha import captcha
from django_redis import get_redis_connection
from . import constants
from django import http
from django.views import View
from meiduo.utils.response_code import RETCODE
import random


class ImagecodeView(View):
    def get(self, request, uuid):
        # 生成图形验证码数据:字符code,图片image,得到验证码字符以及图片
        text, code, image = captcha.generate_captcha()
        # 获取redis连接对象
        redis_cli = get_redis_connection('verify_code')
        # 向redis中写数据
        redis_cli.setex(uuid, constants.IMAGE_CODE_EXPIRES, code)

        return http.HttpResponse(image, content_type='image/png')


class SmscodeView(View):
    def get(self, request, mobile):
        # 接收
        image_code = request.GET.get('image_code')  # 接收的图形验证码文本
        image_code_id = request.GET.get('image_code_id')  # 图形验证码唯一标识

        # 验证
        # 验证图片验证码
        # 1.连接redis
        redis_cli = get_redis_connection('verify_code')
        redis_pl = redis_cli.pipeline()
        # 2.从redis中根据image_code_id(键)获取image_code(图片验证码字符)
        image_code_redis = redis_cli.get(image_code_id)
        # 3.判断是否redis中是否存在此键值对,即判断是否过期
        if not image_code_redis:
            return http.JsonResponse({
                'code': RETCODE.PARAMERR,
                'errmsg': '图形验证码已过期'
            })
        # 4.强制过期
        redis_cli.delete(image_code_id)
        # 5.判断是否正确,验证码忽略大小写
        if image_code_redis.decode() != image_code.upper():
                return http.JsonResponse({
                'code': RETCODE.PARAMERR,
                'errmsg': '图形验证码错误'
            })
        # 6.是否已经向此手机号发送过短信
        if redis_cli.get('sms_flag_' + mobile):
            return http.JsonResponse({
                'code': RETCODE.PARAMERR,
                'errmsg': '已经向此手机号发过短信，请查看手机'
            })
        # 处理

        # 1.生成6位随机数
        sms_code = '%06d' % random.randint(0, 999999)
        print(sms_code)
        # 2.保存到redis,键为:sms_13327437752
        redis_pl.setex('sms_' + mobile, constants.SMS_CODE_EXPIRES, sms_code)
        # 3.存储60s发送的标记
        redis_pl.setex('sms_flag_' + mobile, constants.SMS_CODE_FLAG_EXPIRES, 1)
        redis_pl.execute()
        # 响应
        return http.JsonResponse({
            'code': RETCODE.OK,
            'errmsg': 'OK'
        })
